==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/TokenPayLoadDataContextAllOfPolicyRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The authorization server policy rule used to mint the token
 */
@ApiModel(description = "The authorization server policy rule used to mint the token")
@JsonPropertyOrder({ TokenPayLoadDataContextAllOfPolicyRule.JSON_PROPERTY_ID })
@JsonTypeName("TokenPayLoad_data_context_allOf_policy_rule")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TokenPayLoadDataContextAllOfPolicyRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public TokenPayLoadDataContextAllOfPolicyRule() {
    }

    public TokenPayLoadDataContextAllOfPolicyRule id(String id) {

        this.id = id;
        return this;
    }

    /**
     * The unique identifier for the policy rule
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "0pr4ktb7elD3ZvrMy0g7", value = "The unique identifier for the policy rule")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TokenPayLoadDataContextAllOfPolicyRule tokenPayLoadDataContextAllOfPolicyRule = (TokenPayLoadDataContextAllOfPolicyRule) o;
        return Objects.equals(this.id, tokenPayLoadDataContextAllOfPolicyRule.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TokenPayLoadDataContextAllOfPolicyRule {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/TokenPayLoadDataContextAllOfPolicyRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The authorization server policy rule used to mint the token
 */
@ApiModel(description = "The authorization server policy rule used to mint the token")
@JsonPropertyOrder({ TokenPayLoadDataContextAllOfPolicyRule.JSON_PROPERTY_ID })
@JsonTypeName("TokenPayLoad_data_context_allOf_policy_rule")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TokenPayLoadDataContextAllOfPolicyRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public TokenPayLoadDataContextAllOfPolicyRule() {
    }

    public TokenPayLoadDataContextAllOfPolicyRule id(String id) {

        this.id = id;
        return this;
    }

    /**
     * The unique identifier for the policy rule
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "0pr4ktb7elD3ZvrMy0g7", value = "The unique identifier for the policy rule")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TokenPayLoadDataContextAllOfPolicyRule tokenPayLoadDataContextAllOfPolicyRule = (TokenPayLoadDataContextAllOfPolicyRule) o;
        return Objects.equals(this.id, tokenPayLoadDataContextAllOfPolicyRule.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TokenPayLoadDataContextAllOfPolicyRule {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
